@@ -1,28 +1,16 @@
 /*
- * Copyright (C) 2014  Daniel Vratil <dvratil@redhat.com>
+ * SPDX-FileCopyrightText: 2014 Daniel Vratil <dvratil@redhat.com>
  *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Lesser General Public
- * License as published by the Free Software Foundation; either
- * version 2.1 of the License, or (at your option) any later version.
- *
- * This library is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Lesser General Public License for more details.
- *
- * You should have received a copy of the GNU Lesser General Public
- * License along with this library; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
+ * SPDX-License-Identifier: LGPL-2.1-or-later
  *
  */
 
 #include "backendloader.h"
+#include "abstractbackend.h"
 #include "backenddbuswrapper.h"
 #include "backendloaderadaptor.h"
+#include "backendmanager_p.h"
 #include "kscreen_backendLauncher_debug.h"
-#include "src/abstractbackend.h"
-#include "src/backendmanager_p.h"
 
 #include <QCoreApplication>
 #include <QDBusConnectionInterface>
