@@ -7,6 +7,7 @@
 #include "doctor.h"
 #include "dpmsclient.h"
 
+#include <QCollator>
 #include <QCommandLineParser>
 #include <QCoreApplication>
 #include <QDateTime>
@@ -144,12 +145,11 @@ void Doctor::showDpms()
 void Doctor::showBackends() const
 {
     cout << "Environment: " << Qt::endl;
-    auto env_kscreen_backend = (qgetenv("KSCREEN_BACKEND").isEmpty()) ? QStringLiteral("[not set]") : QString::fromUtf8(qgetenv("KSCREEN_BACKEND"));
+    auto env_kscreen_backend = qEnvironmentVariable("KSCREEN_BACKEND", QStringLiteral("[not set]"));
     cout << "  * KSCREEN_BACKEND           : " << env_kscreen_backend << Qt::endl;
-    auto env_kscreen_backend_inprocess =
-        (qgetenv("KSCREEN_BACKEND_INPROCESS").isEmpty()) ? QStringLiteral("[not set]") : QString::fromUtf8(qgetenv("KSCREEN_BACKEND_INPROCESS"));
+    auto env_kscreen_backend_inprocess = qEnvironmentVariable("KSCREEN_BACKEND_INPROCESS", QStringLiteral("[not set]"));
     cout << "  * KSCREEN_BACKEND_INPROCESS : " << env_kscreen_backend_inprocess << Qt::endl;
-    auto env_kscreen_logging = (qgetenv("KSCREEN_LOGGING").isEmpty()) ? QStringLiteral("[not set]") : QString::fromUtf8(qgetenv("KSCREEN_LOGGING"));
+    auto env_kscreen_logging = qEnvironmentVariable("KSCREEN_LOGGING", QStringLiteral("[not set]"));
     cout << "  * KSCREEN_LOGGING           : " << env_kscreen_logging << Qt::endl;
 
     cout << "Logging to                : " << (Log::instance()->enabled() ? Log::instance()->logFile() : QStringLiteral("[logging disabled]")) << Qt::endl;
@@ -297,6 +297,25 @@ void Doctor::parseOutputArgs()
                         qApp->exit(9);
                         return;
                     }
+                } else if (ops.count() == 4 && ops[2] == QLatin1String("rgbrange")) {
+                    const QString _range = ops[3].toLower();
+                    KScreen::Output::RgbRange range;
+                    if (_range == QStringLiteral("automatic")) {
+                        range = KScreen::Output::RgbRange::Automatic;
+                    } else if (_range == QStringLiteral("full")) {
+                        range = KScreen::Output::RgbRange::Full;
+                    } else if (_range == QStringLiteral("limited")) {
+                        range = KScreen::Output::RgbRange::Limited;
+                    } else {
+                        qCDebug(KSCREEN_DOCTOR) << "Wrong input: Only allowed values for rgbrange are \"automatic\", \"full\" and \"limited\"";
+                        qApp->exit(9);
+                        return;
+                    }
+                    if (!setRgbRange(output_id, range)) {
+                        qCDebug(KSCREEN_DOCTOR) << "Could not set rgb range " << range << " to output " << output_id;
+                        qApp->exit(9);
+                        return;
+                    }
                 } else {
                     cerr << "Unable to parse arguments: " << op << Qt::endl;
                     qApp->exit(2);
@@ -361,6 +380,9 @@ void Doctor::showOutputs() const
     typeString[KScreen::Output::TVC4] = QStringLiteral("TVC4");
     typeString[KScreen::Output::DisplayPort] = QStringLiteral("DisplayPort");
 
+    QCollator collator;
+    collator.setNumericMode(true);
+
     for (const auto &output : m_config->outputs()) {
         cout << green << "Output: " << cr << output->id() << " " << output->name();
         cout << " " << (output->isEnabled() ? green + QLatin1String("enabled") : red + QLatin1String("disabled"));
@@ -369,7 +391,14 @@ void Doctor::showOutputs() const
         auto _type = typeString[output->type()];
         cout << " " << yellow << (_type.isEmpty() ? QStringLiteral("UnmappedOutputType") : _type);
         cout << blue << " Modes: " << cr;
-        for (const auto &mode : output->modes()) {
+
+        const auto modes = output->modes();
+        auto modeKeys = modes.keys();
+        std::sort(modeKeys.begin(), modeKeys.end(), collator);
+
+        for (const auto &key : modeKeys) {
+            auto mode = *modes.find(key);
+
             auto name = QStringLiteral("%1x%2@%3")
                             .arg(QString::number(mode->size().width()), QString::number(mode->size().height()), QString::number(qRound(mode->refreshRate())));
             if (mode == output->currentMode()) {
@@ -400,6 +429,21 @@ void Doctor::showOutputs() const
         } else {
             cout << cr << "incapable ";
         }
+        cout << yellow << "RgbRange: ";
+        if (output->capabilities() & Output::Capability::RgbRange) {
+            switch (output->rgbRange()) {
+            case Output::RgbRange::Automatic:
+                cout << cr << "Automatic ";
+                break;
+            case Output::RgbRange::Full:
+                cout << cr << "Full ";
+                break;
+            case Output::RgbRange::Limited:
+                cout << cr << "Limited ";
+            }
+        } else {
+            cout << cr << "unknown ";
+        }
         if (output->isPrimary()) {
             cout << blue << "primary";
         }
@@ -551,6 +595,24 @@ bool Doctor::setVrrPolicy(int id, KScreen::Output::VrrPolicy policy)
     return false;
 }
 
+bool Doctor::setRgbRange(int id, KScreen::Output::RgbRange rgbRange)
+{
+    if (!m_config) {
+        qCWarning(KSCREEN_DOCTOR) << "Invalid config.";
+        return false;
+    }
+
+    for (const auto &output : m_config->outputs()) {
+        if (output->id() == id) {
+            output->setRgbRange(rgbRange);
+            m_changed = true;
+            return true;
+        }
+    }
+    cout << "Output RgbRange " << id << " invalid." << Qt::endl;
+    return false;
+}
+
 void Doctor::applyConfig()
 {
     if (!m_changed) {
